-- Create the database and connect to it.
connect 'jdbc:derby://localhost:1527/customerdb;create=true';

-- Add a user to the database, username dev, password dev
CALL SYSCS_UTIL.SYSCS_SET_DATABASE_PROPERTY('derby.user.dev','dev');

-- Grant all privileges to user dev
CALL SYSCS_UTIL.SYSCS_SET_DATABASE_PROPERTY('derby.database.fullAccessUsers','dev');

-- Disconnect from the newly created database
disconnect;

-- Reconnect to the newly created database as user dev
connect 'jdbc:derby://localhost:1527/customerdb;user=dev;password=dev';

-- Create tables
CREATE TABLE CUSTOMERS (CUSTOMER_ID INT PRIMARY KEY, FIRST_NAME VARCHAR(20), LAST_NAME VARCHAR(20), EMAIL VARCHAR(30));
CREATE TABLE TELEPHONE_TYPES(TELEPHONE_TYPE_ID INT PRIMARY KEY, TELEPHONE_TYPE_CD CHAR(1), TELEPHONE_TYPE_TEXT VARCHAR(20));
CREATE TABLE TELEPHONES (TELEPHONE_ID INT PRIMARY KEY, TELEPHONE_TYPE_ID INT REFERENCES TELEPHONE_TYPES, CUSTOMER_ID INT REFERENCES CUSTOMERS, TELEPHONE_NUMBER CHAR(12));
CREATE TABLE ADDRESS_TYPES (ADDRESS_TYPE_ID INT PRIMARY KEY, ADDRESS_TYPE_CODE CHAR(1), ADDRESS_TYPE_TEXT VARCHAR(20));
CREATE TABLE US_STATES(US_STATE_ID INT PRIMARY KEY, US_STATE_CD CHAR(2) NOT NULL, US_STATE_NM VARCHAR(30) NOT NULL);
CREATE TABLE ADDRESSES (ADDRESS_ID INT PRIMARY KEY, ADDRESS_TYPE_ID INT REFERENCES ADDRESS_TYPES, CUSTOMER_ID INT REFERENCES CUSTOMERS,
ADDR_LINE_1 VARCHAR(100), ADDR_LINE_2 VARCHAR(100), CITY VARCHAR (100), US_STATE_ID INT REFERENCES US_STATES, ZIP CHAR(5));
CREATE TABLE LOGIN_INFO (LOGIN_INFO_ID INT PRIMARY KEY, CUSTOMER_ID INT REFERENCES CUSTOMERS, LOGIN_NAME VARCHAR(10), PASSWORD VARCHAR (15));
CREATE TABLE ORDERS(ORDER_ID INT PRIMARY KEY, CUSTOMER_ID INT REFERENCES CUSTOMERS, ORDER_NUMBER VARCHAR (10), ORDER_DESCRIPTION VARCHAR(200));
CREATE TABLE ITEMS(ITEM_ID INT PRIMARY KEY, ITEM_NUMBER VARCHAR(10), ITEM_SHORT_DESC VARCHAR(100), ITEM_LONG_DESC VARCHAR(500));
CREATE TABLE ORDER_ITEMS(ORDER_ID INT REFERENCES ORDERS, ITEM_ID INT REFERENCES ITEMS, ITEM_QTY INTEGER);

-- Populate tables
INSERT INTO TELEPHONE_TYPES (TELEPHONE_TYPE_ID, TELEPHONE_TYPE_CD, TELEPHONE_TYPE_TEXT) VALUES (1, 'H', 'Home');
INSERT INTO TELEPHONE_TYPES (TELEPHONE_TYPE_ID, TELEPHONE_TYPE_CD, TELEPHONE_TYPE_TEXT) VALUES (2, 'W', 'Work');
INSERT INTO TELEPHONE_TYPES (TELEPHONE_TYPE_ID, TELEPHONE_TYPE_CD, TELEPHONE_TYPE_TEXT) VALUES (3, 'C', 'Cell');

INSERT INTO ADDRESS_TYPES(ADDRESS_TYPE_ID, ADDRESS_TYPE_CODE, ADDRESS_TYPE_TEXT) VALUES (1, 'H', 'Home');
INSERT INTO ADDRESS_TYPES(ADDRESS_TYPE_ID, ADDRESS_TYPE_CODE, ADDRESS_TYPE_TEXT) VALUES (2, 'M', 'Mailing');
INSERT INTO ADDRESS_TYPES(ADDRESS_TYPE_ID, ADDRESS_TYPE_CODE, ADDRESS_TYPE_TEXT) VALUES (3, 'S', 'Shipping');

INSERT INTO "DEV"."US_STATES" (US_STATE_ID,US_STATE_CD,US_STATE_NM) VALUES (1,'AL','Alabama');
INSERT INTO "DEV"."US_STATES" (US_STATE_ID,US_STATE_CD,US_STATE_NM) VALUES (2,'AK','Alaska');
INSERT INTO "DEV"."US_STATES" (US_STATE_ID,US_STATE_CD,US_STATE_NM) VALUES (3,'AZ','Arizona');
INSERT INTO "DEV"."US_STATES" (US_STATE_ID,US_STATE_CD,US_STATE_NM) VALUES (4,'AR','Arkansas');
INSERT INTO "DEV"."US_STATES" (US_STATE_ID,US_STATE_CD,US_STATE_NM) VALUES (5,'CA','California');
INSERT INTO "DEV"."US_STATES" (US_STATE_ID,US_STATE_CD,US_STATE_NM) VALUES (6,'CO','Colorado');
INSERT INTO "DEV"."US_STATES" (US_STATE_ID,US_STATE_CD,US_STATE_NM) VALUES (7,'CT','Conneticut');
INSERT INTO "DEV"."US_STATES" (US_STATE_ID,US_STATE_CD,US_STATE_NM) VALUES (8,'DE','Delaware');
INSERT INTO "DEV"."US_STATES" (US_STATE_ID,US_STATE_CD,US_STATE_NM) VALUES (9,'DC','District of Columbia');
INSERT INTO "DEV"."US_STATES" (US_STATE_ID,US_STATE_CD,US_STATE_NM) VALUES (10,'FL','Florida');
INSERT INTO "DEV"."US_STATES" (US_STATE_ID,US_STATE_CD,US_STATE_NM) VALUES (11,'GA','Georgia');
INSERT INTO "DEV"."US_STATES" (US_STATE_ID,US_STATE_CD,US_STATE_NM) VALUES (12,'IL','Illinois');
INSERT INTO "DEV"."US_STATES" (US_STATE_ID,US_STATE_CD,US_STATE_NM) VALUES (13,'IN','Indiana');
INSERT INTO "DEV"."US_STATES" (US_STATE_ID,US_STATE_CD,US_STATE_NM) VALUES (14,'IA','Iowa');
INSERT INTO "DEV"."US_STATES" (US_STATE_ID,US_STATE_CD,US_STATE_NM) VALUES (15,'KS','Kansas');
INSERT INTO "DEV"."US_STATES" (US_STATE_ID,US_STATE_CD,US_STATE_NM) VALUES (16,'KY','Kentucky');
INSERT INTO "DEV"."US_STATES" (US_STATE_ID,US_STATE_CD,US_STATE_NM) VALUES (17,'LA','Louisiana');
INSERT INTO "DEV"."US_STATES" (US_STATE_ID,US_STATE_CD,US_STATE_NM) VALUES (18,'ME','Maine');
INSERT INTO "DEV"."US_STATES" (US_STATE_ID,US_STATE_CD,US_STATE_NM) VALUES (19,'MD','Maryland');
INSERT INTO "DEV"."US_STATES" (US_STATE_ID,US_STATE_CD,US_STATE_NM) VALUES (20,'MA','Massachusetts');
INSERT INTO "DEV"."US_STATES" (US_STATE_ID,US_STATE_CD,US_STATE_NM) VALUES (21,'MI','Michigan');
INSERT INTO "DEV"."US_STATES" (US_STATE_ID,US_STATE_CD,US_STATE_NM) VALUES (22,'MN','Minnesota');
INSERT INTO "DEV"."US_STATES" (US_STATE_ID,US_STATE_CD,US_STATE_NM) VALUES (23,'MS','Mississippi');
INSERT INTO "DEV"."US_STATES" (US_STATE_ID,US_STATE_CD,US_STATE_NM) VALUES (24,'MO','Missouri');
INSERT INTO "DEV"."US_STATES" (US_STATE_ID,US_STATE_CD,US_STATE_NM) VALUES (25,'MT','Montana');
INSERT INTO "DEV"."US_STATES" (US_STATE_ID,US_STATE_CD,US_STATE_NM) VALUES (26,'NE','Nebraska');
INSERT INTO "DEV"."US_STATES" (US_STATE_ID,US_STATE_CD,US_STATE_NM) VALUES (27,'NV','Nevada');
INSERT INTO "DEV"."US_STATES" (US_STATE_ID,US_STATE_CD,US_STATE_NM) VALUES (28,'NH','New Hampshire');
INSERT INTO "DEV"."US_STATES" (US_STATE_ID,US_STATE_CD,US_STATE_NM) VALUES (29,'NJ','New Jersey');
INSERT INTO "DEV"."US_STATES" (US_STATE_ID,US_STATE_CD,US_STATE_NM) VALUES (30,'NM','New Mexico');
INSERT INTO "DEV"."US_STATES" (US_STATE_ID,US_STATE_CD,US_STATE_NM) VALUES (31,'NY','New York');
INSERT INTO "DEV"."US_STATES" (US_STATE_ID,US_STATE_CD,US_STATE_NM) VALUES (32,'NC','North Carolina');
INSERT INTO "DEV"."US_STATES" (US_STATE_ID,US_STATE_CD,US_STATE_NM) VALUES (33,'ND','North Dakota');
INSERT INTO "DEV"."US_STATES" (US_STATE_ID,US_STATE_CD,US_STATE_NM) VALUES (34,'OH','Ohio');
INSERT INTO "DEV"."US_STATES" (US_STATE_ID,US_STATE_CD,US_STATE_NM) VALUES (35,'OK','Oklahoma');
INSERT INTO "DEV"."US_STATES" (US_STATE_ID,US_STATE_CD,US_STATE_NM) VALUES (36,'OR','Oregon');
INSERT INTO "DEV"."US_STATES" (US_STATE_ID,US_STATE_CD,US_STATE_NM) VALUES (37,'PA','Pennsylvania');
INSERT INTO "DEV"."US_STATES" (US_STATE_ID,US_STATE_CD,US_STATE_NM) VALUES (38,'OK','Oklahoma');
INSERT INTO "DEV"."US_STATES" (US_STATE_ID,US_STATE_CD,US_STATE_NM) VALUES (39,'RI','Rhode Island');
INSERT INTO "DEV"."US_STATES" (US_STATE_ID,US_STATE_CD,US_STATE_NM) VALUES (40,'SC','South Carolina');
INSERT INTO "DEV"."US_STATES" (US_STATE_ID,US_STATE_CD,US_STATE_NM) VALUES (41,'SD','South Dakota');
INSERT INTO "DEV"."US_STATES" (US_STATE_ID,US_STATE_CD,US_STATE_NM) VALUES (42,'TN','Tennessee');
INSERT INTO "DEV"."US_STATES" (US_STATE_ID,US_STATE_CD,US_STATE_NM) VALUES (43,'Tx','Texas');
INSERT INTO "DEV"."US_STATES" (US_STATE_ID,US_STATE_CD,US_STATE_NM) VALUES (44,'SC','South Carolina');
INSERT INTO "DEV"."US_STATES" (US_STATE_ID,US_STATE_CD,US_STATE_NM) VALUES (45,'UT','Utah');
INSERT INTO "DEV"."US_STATES" (US_STATE_ID,US_STATE_CD,US_STATE_NM) VALUES (46,'VT','Vermont');
INSERT INTO "DEV"."US_STATES" (US_STATE_ID,US_STATE_CD,US_STATE_NM) VALUES (47,'VA','Virginia');
INSERT INTO "DEV"."US_STATES" (US_STATE_ID,US_STATE_CD,US_STATE_NM) VALUES (48,'WA','Washington');
INSERT INTO "DEV"."US_STATES" (US_STATE_ID,US_STATE_CD,US_STATE_NM) VALUES (49,'WV','West Virginia');
INSERT INTO "DEV"."US_STATES" (US_STATE_ID,US_STATE_CD,US_STATE_NM) VALUES (50,'WI','Winsconsin');
INSERT INTO "DEV"."US_STATES" (US_STATE_ID,US_STATE_CD,US_STATE_NM) VALUES (51,'WY','Wyoming');